@@ -46,7 +46,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MINOR_VERSION (22)
+#define GTK_SOURCE_MINOR_VERSION (24)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -57,7 +57,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MICRO_VERSION (2)
+#define GTK_SOURCE_MICRO_VERSION (8)
 
 
 /**
@@ -207,6 +207,16 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_3_22 (G_ENCODE_VERSION (3, 22))
 
+/**
+ * GTK_SOURCE_VERSION_3_24:
+ *
+ * A macro that evaluates to the 3.24 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 3.24
+ */
+#define GTK_SOURCE_VERSION_3_24 (G_ENCODE_VERSION (3, 24))
+
 #ifndef __GTK_DOC_IGNORE__
 #if (GTK_SOURCE_MINOR_VERSION % 2)
 #define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION, GTK_SOURCE_MINOR_VERSION + 1))
@@ -502,6 +512,24 @@ G_BEGIN_DECLS
 #endif
 #endif /* __GTK_DOC_IGNORE__ */
 
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MIN_REQUIRED >= GTK_SOURCE_VERSION_3_24
+#define GTK_SOURCE_DEPRECATED_IN_3_24 G_DEPRECATED _GTK_SOURCE_EXTERN
+#define GTK_SOURCE_DEPRECATED_IN_3_24_FOR(f) G_DEPRECATED_FOR(f) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_DEPRECATED_IN_3_24 _GTK_SOURCE_EXTERN
+#define GTK_SOURCE_DEPRECATED_IN_3_24_FOR(f) _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_3_24
+#define GTK_SOURCE_AVAILABLE_IN_3_24 G_UNAVAILABLE(3, 24) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_AVAILABLE_IN_3_24 _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
 GTK_SOURCE_AVAILABLE_IN_3_20
 guint		gtk_source_get_major_version		(void);
 
